==> abg_utils-3.0.7.tar.gz: lib/src/model/rating.dart <==
import 'dart:io';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_auth/firebase_auth.dart';
import '../../abg_utils.dart';

Future<String?> addRating(int rating, String text, List<String> images, OrderData jobInfo) async{
  User? user = FirebaseAuth.instance.currentUser;
  if (user == null)
    return "addRating user == null";
  List<ImageData> _images = [];
  try{
    for (var item in images){
      var ret = await uploadImage("rating", File(item).readAsBytesSync());
      if (ret != null)
        return ret;
      // var f = Uuid().v4();
      // var name = "rate/$f.jpg";
      // var firebaseStorageRef = FirebaseStorage.instance.ref().child(name);
      // TaskSnapshot s = await firebaseStorageRef.putFile(File(item));
      // _images.add(ImageData(localFile: name, serverPath: await s.ref.getDownloadURL()));
      _images.add(ImageData(localFile: localFile, serverPath: serverPath));
    }
    //
    await FirebaseFirestore.instance.collection("service").doc(jobInfo.serviceId).set({
      "rating$rating": FieldValue.increment(1),
      "timeModify": FieldValue.serverTimestamp(),
    }, SetOptions(merge:true));
    await FirebaseFirestore.instance.collection("reviews").add({
      "rating": rating,
      "text": text,
      "images": _images.map((i) => i.toJson()).toList(),
      "user": user.uid,
      "service": jobInfo.serviceId,
      'serviceName': getTextByLocale(jobInfo.service, locale),
      "provider": jobInfo.providerId,
      "userName": userAccountData.userName,
      "userAvatar": userAccountData.userAvatar,
      'time': FieldValue.serverTimestamp(),
    });
    await FirebaseFirestore.instance.collection("booking").doc(jobInfo.id).set({
      "rated": true,
      "timeModify": FieldValue.serverTimestamp(),
    }, SetOptions(merge:true));
    await FirebaseFirestore.instance.collection("settings").doc("main")
        .set({"service_reviews": FieldValue.increment(1)}, SetOptions(merge:true));
  } catch (e) {
    return "addRating " + e.toString();
  }
  jobInfo.rated = true;
  return null;
}

==> abg_utils-3.1.0.tar.gz: lib/src/model/rating.dart <==
import 'dart:typed_data';
import 'package:cloud_firestore/cloud_firestore.dart';
import 'package:firebase_auth/firebase_auth.dart';
import '../../abg_utils.dart';

Future<String?> addRating(int rating, String text, List<Uint8List> images, OrderData jobInfo) async{
  User? user = FirebaseAuth.instance.currentUser;
  if (user == null)
    return "addRating user == null";
  List<ImageData> _images = [];
  try{
    for (var item in images){
      var ret = await uploadImage("rating", item);
      if (ret != null)
        return ret;
      // var f = Uuid().v4();
      // var name = "rate/$f.jpg";
      // var firebaseStorageRef = FirebaseStorage.instance.ref().child(name);
      // TaskSnapshot s = await firebaseStorageRef.putFile(File(item));
      // _images.add(ImageData(localFile: name, serverPath: await s.ref.getDownloadURL()));
      _images.add(ImageData(localFile: localFile, serverPath: serverPath));
    }
    //
    await FirebaseFirestore.instance.collection("service").doc(jobInfo.serviceId).set({
      "rating$rating": FieldValue.increment(1),
      "timeModify": FieldValue.serverTimestamp(),
    }, SetOptions(merge:true));
    await FirebaseFirestore.instance.collection("reviews").add({
      "rating": rating,
      "text": text,
      "images": _images.map((i) => i.toJson()).toList(),
      "user": user.uid,
      "service": jobInfo.serviceId,
      'serviceName': getTextByLocale(jobInfo.service, locale),
      "provider": jobInfo.providerId,
      "userName": userAccountData.userName,
      "userAvatar": userAccountData.userAvatar,
      'time': FieldValue.serverTimestamp(),
    });
    await FirebaseFirestore.instance.collection("booking").doc(jobInfo.id).set({
      "rated": true,
      "timeModify": FieldValue.serverTimestamp(),
    }, SetOptions(merge:true));
    await FirebaseFirestore.instance.collection("settings").doc("main")
        .set({"service_reviews": FieldValue.increment(1)}, SetOptions(merge:true));
  } catch (e) {
    return "addRating " + e.toString();
  }
  jobInfo.rated = true;
  return null;
}
